@@ -1,7 +1,7 @@
 package Date::Holidays::USA;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: DEPRECATED - Provides United States of America holidays
+# ABSTRACT: Provides United States of America holidays
 
 use warnings;
 use strict;
@@ -13,7 +13,7 @@ use Exporter qw(import);
 
 our @EXPORT = qw(is_holiday holidays);
 
-our $VERSION = '0.0208_1';
+our $VERSION = '0.0100';
 
 
 sub new {
@@ -31,7 +31,7 @@ sub is_holiday {
 }
 
 
-sub us_holidays {
+sub holidays {
     my ($self, $year) = @_;
     unless ($year) {
       $year = (localtime)[5];
@@ -39,7 +39,6 @@ sub us_holidays {
     }
     my %dom = (
         memorial     => _nth_day_of_month(-1, 1, $year, 5),
-        mothers      => _nth_day_of_month(2, 7, $year, 5),
         fathers      => _nth_day_of_month(3, 7, $year, 6),
         labor        => _nth_day_of_month(1, 1, $year, 9),
         columbus     => _nth_day_of_month(2, 1, $year, 10),
@@ -47,42 +46,41 @@ sub us_holidays {
     );
     my %holidays = (
         1 => {
-            1  => "New Year's Day",
+            1  => "New Year's",
             15 => 'Martin Luther King Jr.',
         },
         2 => {
-            14 => "Valentine's Day",
-            19 => "President's Day",
+            14 => "Valentine's",
+            19 => "President's",
         },
         3 => {
-            17 => "St. Patrick's Day",
+            17 => "St. Patrick's",
         },
         4 => {
         },
         5 => {
             5 => 'Cinco de Mayo',
-            $dom{mothers}  => "Mother's Day",
-            $dom{memorial} => 'Memorial Day',
+            $dom{memorial} => 'Memorial',
         },
         6 => {
-            14 => 'Flag Day',
-            $dom{fathers} => "Father's Day",
+            14 => 'Flag',
+            $dom{fathers} => "Father's",
             19 => 'Juneteenth',
         },
         7 => {
-            4 => 'Independence Day',
+            4 => 'Independence',
         },
         8 => {
         },
         9 => {
-            $dom{labor} => 'Labor Day',
+            $dom{labor} => 'Labor',
         },
         10 => {
-            $dom{columbus} => "Columbus; Indigenous Peoples' Day",
+            $dom{columbus} => "Columbus; Indigenous Peoples'",
             31 => 'Halloween'
         },
         11 => {
-            11 => "Veteran's Day",
+            11 => 'Veterans',
             $dom{thanksgiving} => 'Thanksgiving',
         },
         12 => {
@@ -93,18 +91,11 @@ sub us_holidays {
     );
     my ($month, $day) = easter($year);
     $holidays{$month}->{$day} = 'Easter';
-    return \%holidays;
-}
-
-
-sub holidays {
-    my ($self, $year) = @_;
-    my $holidays = $self->us_holidays($year);
     my %rtn;
-    for my $month (sort { $a <=> $b } keys %$holidays) {
-        for my $day (sort { $a <=> $b } keys %{ $holidays->{$month} }) {
-            $rtn{ sprintf '%02d%02d', $month, $day } = $holidays->{$month}->{$day}
-                if $holidays->{$month}->{$day};
+    for $month (sort { $a <=> $b } keys %holidays) {
+        for $day (sort { $a <=> $b } keys %{ $holidays{$month} }) {
+            $rtn{ sprintf '%02d%02d', $month, $day } = $holidays{$month}->{$day}
+                if $holidays{$month}->{$day};
         }
     }
     return \%rtn;
@@ -145,31 +136,36 @@ __END__
 
 =head1 NAME
 
-Date::Holidays::USA - DEPRECATED - Provides United States of America holidays
+Date::Holidays::USA - Provides United States of America holidays
 
 =head1 VERSION
 
-version 0.0208_1
+version 0.0100
 
 =head1 SYNOPSIS
 
-  # Using with the Date::Holidays module:
+  # Using with the Date::Holidays module (recommended):
   use Date::Holidays ();
   my $dh = Date::Holidays->new(countrycode => 'USA', nocheck => 1);
-  print $dh->is_holiday(year => 2024, month => 1, day => 1), "\n";
+  my ($year, $month, $day) = (localtime)[5, 4, 3];
+  $year  += 1900;
+  $month += 1;
+  print "Woohoo!\n" if $dh->is_holiday($year, $month, $day);
   my $h = $dh->holidays;
 
   # Using the Date::Holidays::USA module directly:
   use Date::Holidays::USA ();
   $dh = Date::Holidays::USA->new;
-  print $dh->is_holiday(2024, 1, 1), "\n";
-  $h = $dh->holidays;
-  $h = $dh->us_holidays(2032);
+  print "Woohoo!\n" if $dh->is_holiday($year, $month, $day);
+  $h = $dh->holidays($year);
 
 =head1 DESCRIPTION
 
-C<Date::Holidays::USA> is a now deprecated module that provided United
-States of America holidays.
+C<Date::Holidays::USA> provides United States of America holidays.
+
+=head1 NAME
+
+Date::Holidays::USA - Provides United States of America holidays
 
 =head1 METHODS
 
@@ -181,7 +177,7 @@ Return a new C<Date::Holidays::USA> object.
 
 =head2 is_holiday
 
-  $holiday = $dh->is_holiday($year, $month, $day);
+  $holiday = is_holiday($year, $month, $day);
 
 Takes three arguments:
 
@@ -191,30 +187,13 @@ Takes three arguments:
 
 Returns the name of the holiday, if one exists on that day.
 
-=head2 us_holidays
+=head2 holidays
 
-  $holidays = $dh->us_holidays;
-  $holidays = $dh->us_holidays($year);
+  my $holidays = holidays($year);
 
 Returns a hash reference of holiday names, where the keys are by month
 and day.
 
-=head2 holidays
-
-  $holidays = $dh->holidays;
-  $holidays = $dh->holidays($year);
-
-Returns a hash reference of holiday names, where the keys are 4 digit
-strings month and day.
-
-=head1 SEE ALSO
-
-L<Date::Holidays>
-
-L<Date::Holidays::Adapter>
-
-L<Date::Holidays::Adapter::USA>
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
